from django.contrib.sitemaps import Sitemap
from blog.models import BlogPost
from kisan.models import ProductData, Category, SubCategory

class BlogPostSitemap(Sitemap):
    changefreq = 'weekly'
    priority = 0.8

    def items(self):
        return BlogPost.objects.all()

    def location(self, obj):
        return obj.get_absolute_url()


class StaticViewSitemap(Sitemap):
    changefreq = 'monthly'
    priority = 0.5

    def items(self):
        return [
            '/about/',
            '/enquiry/',
        ]

    def location(self, obj):
        return obj

sitemaps = {
    'blog': BlogPostSitemap,
    'static': StaticViewSitemap,
}



class CategorySitemap(Sitemap):
    changefreq = 'weekly'
    priority = 0.8

    def items(self):
        return Category.objects.all()

    def location(self, obj):
        return f"/{obj.cat_title}/{obj.id}/"


class SubCategorySitemap(Sitemap):
    changefreq = 'weekly'
    priority = 0.8

    def items(self):
        return SubCategory.objects.all()

    def location(self, obj):
        return f"/{obj.category}/{obj.sub_title}/{obj.id}/"